# appfw

An application framework with external configuration, logging and commandline
parsing support.

## Installation

    pip install appfw

## Usage

Type

    app-init

to start. Use following line to get help on commandline options:

    app-init --help

